@@ -39,10 +39,10 @@ namespace ARTICLE
 
         virtual void restore();
         virtual void switch_admin();
-        virtual void set_tabicon( const std::string& url, const std::string& iconname );
 
       private:
         void delete_popup();
+        void delete_all_popups();
 
         virtual void slot_drag_begin( int page );
         virtual void slot_drag_end();
