@@ -6,8 +6,12 @@
 #define _CONTROLLABEL_H
 
 #include "controlid.h"
+#include "global.h"
 
-#define MAX_CONTROL_LABEL 64
+enum
+{
+    MAX_CONTROL_LABEL = 64
+};
 
 namespace CONTROL
 {
@@ -44,22 +48,22 @@ namespace CONTROL
 
         { "Back", "戻る" },
 
-        { "Quit", "閉じる" },
+        { "Quit", ITEM_NAME_QUIT },
         { "Save", "名前を付けて保存..." },
-        { "Delete", "削除" },
-        { "Reload", "再読み込み" },
-        { "StopLoading", "読み込み中止" },
+        { "Delete", ITEM_NAME_DELETE },
+        { "Reload", ITEM_NAME_RELOAD },
+        { "StopLoading", ITEM_NAME_STOPLOADING },
         { "Copy", "コピー" },
         { "SelectAll", "全て選択" },
-        { "AppendFavorite", "お気に入りに追加..." },
+        { "AppendFavorite", ITEM_NAME_FAVORITE },
         { "Property", "プロパティ..." },
 
-        { "Search", "検索" },
+        { "Search", ITEM_NAME_SEARCH },
         { "CloseSearchBar", "検索バーを閉じる" },
         { "HiLightOff", "ハイライト解除" },
         { "SearchInvert", "前方検索" },
-        { "SearchNext", "次検索" },
-        { "SearchPrev", "前検索" },
+        { "SearchNext", ITEM_NAME_SEARCH_NEXT },
+        { "SearchPrev", ITEM_NAME_SEARCH_PREV },
         { "DrawOutAnd", "AND 抽出" },
         { "DrawOutOr", "OR 抽出" },
 
@@ -73,12 +77,6 @@ namespace CONTROL
         { "DragStartButton", "ドラッグ開始" },
         { "TreeRowSelectionButton", "行範囲選択" },
 
-        
-        { "ScrollUp", "" }, // 上スクロール
-        { "ScrollDown", "" },// 下スクロール
-        { "ScrollLeft", "" }, // 左スクロール
-        { "ScrollRight", "" },// 右スクロール
-
         { "", "" },
 
         // BBSLIST
@@ -102,9 +100,12 @@ namespace CONTROL
 
         { "OpenArticle", "スレを開く" },
         { "OpenArticleTab", "タブでスレを開く" },
-        { "NewArticle", "新スレ作成" },
+        { "NewArticle", ITEM_NAME_NEWARTICLE },
         { "SearchCache", "ログ検索" },
 
+        { "ScrollLeftBoard", "" }, // 左スクロール
+        { "ScrollRightBoard", "" },// 右スクロール
+
         { "OpenArticleButton", "スレを開く" },
         { "OpenArticleTabButton", "タブでスレを開く" },
 
@@ -120,9 +121,12 @@ namespace CONTROL
         { "DownMid", "中速下移動" },
         { "DownFast", "高速下移動" },
 
+        { "PrevRes", "前のレスへ移動" },
+        { "NextRes", "次のレスへ移動" },
+
         { "GotoNew", "新着へ移動" },
-        { "OpenParentBoard", "板を開く" },
-        { "WriteMessage", "書き込み" },
+        { "OpenParentBoard", ITEM_NAME_OPENBOARD },
+        { "WriteMessage", ITEM_NAME_WRITEMSG },
 
         { "PopupWarpButton", "クリックで多重ポップアップモードに移行" },
         { "ReferResButton", "参照レスポップアップ表示" },
@@ -155,6 +159,11 @@ namespace CONTROL
         { "ZoomOutImage", "ズームアウト" },
         { "OrgSizeImage", "元の画像サイズ" },
 
+        { "ScrollUpImage", "" }, // 上スクロール
+        { "ScrollDownImage", "" },// 下スクロール
+        { "ScrollLeftImage", "" }, // 左スクロール
+        { "ScrollRightImage", "" },// 右スクロール
+
         { "CloseImageTabButton", "タブを閉じる" },
 
         { "", "" },
@@ -173,8 +182,11 @@ namespace CONTROL
 
         { "", "" },
 
-        { "CancelWrite", "書き込みビューを閉じる" },
-        { "ExecWrite", "書き込み実行" },
+        { "CancelWrite", ITEM_NAME_QUIT },
+        { "ExecWrite", ITEM_NAME_WRITEMSG },
+        { "InsertText", ITEM_NAME_INSERTTEXT  },
+        { "NotClose", ITEM_NAME_NOTCLOSE },
+        { "Preview", ITEM_NAME_PREVIEW },
 
         { "FocusWrite", "書き込みボタンにフォーカスを移す" },
 
@@ -194,7 +206,7 @@ namespace CONTROL
 
         { "DeleteEdit", "一文字削除" },
         { "BackspEdit", "バックスペース" },
-        { "UndoEdit", "元に戻す(Undo)" },
+        { "UndoEdit", ITEM_NAME_UNDO },
 
         { "InputAA", "アスキーアート入力" },
 
