@@ -22,6 +22,7 @@
 #include "global.h"
 #include "login2ch.h"
 #include "session.h"
+#include "updatemanager.h"
 
 #include <sstream>
 
@@ -75,6 +76,7 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
 #endif
 
     memset( &m_access_time, 0, sizeof( struct timeval ) );
+    memset( &m_check_update_time, 0, sizeof( struct timeval ) );
     memset( &m_write_time, 0, sizeof( struct timeval ) );
 
     // m_url にURLセット
@@ -272,6 +274,15 @@ const std::string ArticleBase::get_res_str( int number, bool ref )
 }
 
 
+//
+// number　番のレスの生文字列を返す
+//
+const std::string ArticleBase::get_raw_res_str( int number )
+{
+    return get_nodetree()->get_raw_res_str( number );
+}
+
+
 //
 // 更新時刻
 //
@@ -369,14 +380,10 @@ void ArticleBase::set_subject( const std::string& subject )
 {
     if( subject.empty() ) return;
 
-    // 特殊文字の置き換え(応急処置)
+    // 特殊文字の置き換え
     if( subject.find( "&" ) != std::string::npos ){
 
-        std::string subject_tmp = subject;
-        subject_tmp = MISC::replace_str( subject_tmp, "&quot;", "\"" );
-        subject_tmp = MISC::replace_str( subject_tmp, "&lt;", "<" );
-        subject_tmp = MISC::replace_str( subject_tmp, "&gt;", ">" );
-        subject_tmp = MISC::replace_str( subject_tmp, "&amp;", "&" );
+        std::string subject_tmp = MISC::html_unescape( subject );
 
         if( subject_tmp != m_subject ){
             m_subject = subject_tmp;
@@ -393,7 +400,7 @@ void ArticleBase::set_subject( const std::string& subject )
 
 void ArticleBase::set_number( int number )
 {
-    if( number && number != m_number ){
+    if( number && number > m_number ){
         m_number = number;
         if( m_number_load < m_number ) m_enable_load = true;
     }
@@ -434,9 +441,26 @@ void ArticleBase::update_writetime()
         // BoardViewの行を更新
         CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
     }
+
+    // 板の書き込み時間も更新
+    DBTREE::board_update_writetime( m_url );
 }
 
 
+//
+// 経過時間(秒)
+//
+const time_t ArticleBase::get_write_pass()
+{
+    time_t ret = 0;
+    struct timeval tv;
+    struct timezone tz;
+
+    if( m_write_time.tv_sec && gettimeofday( &tv, &tz ) == 0 ) ret = MAX( 0, tv.tv_sec - m_write_time.tv_sec );
+
+    return ret;
+}
+
 
 //
 // スレ自体のスレ一覧でのブックマーク
@@ -815,23 +839,47 @@ void ArticleBase::stop_load()
 // DAT落ちの場合はロードしないので、強制的にリロードしたいときは reset_status() で
 // ステータスをリセットしてからロードする
 //
-void ArticleBase::download_dat()
+// check_update == true の時はHEADによる更新チェックをおこなう
+//
+void ArticleBase::download_dat( const bool check_update )
 {
     if( empty() ) return;
 
 #ifdef _DEBUG
-    std::cout << "ArticleBase::download_dat " << m_url << std::endl;;
-    std::cout << "status = " << m_status << std::endl;
+    std::cout << "ArticleBase::download_dat " << m_url << " status = " << m_status << " checkupdate = " << check_update << std::endl;
 #endif
 
-    // DAT落ちしていてログイン中で無い時はロードしない
-    if( ! ( ( m_status & STATUS_OLD ) && ! LOGIN::get_login2ch()->login_now() ) ){
+    struct timeval tv;
+    struct timezone tz;
+    if( gettimeofday( &tv, &tz ) != 0 ) tv.tv_sec = 0;
+
+    if( check_update ){
+
+        if( ! SESSION::is_online() ) return;
+
+        // 一度更新チェックしたらしばらくは再チェックできないようにする
+        time_t passed = 0;
+        if( tv.tv_sec ) passed = MAX( 0, tv.tv_sec - m_check_update_time.tv_sec );
 
 #ifdef _DEBUG
-        std::cout << "start\n";
-#endif       
-        get_nodetree()->download_dat();
+        std::cout << "check_update passed = " << passed << std::endl;
+#endif
+
+        if( passed <= CHECKUPDATE_MINSEC ) return;
     }
+
+    if( SESSION::is_online() && tv.tv_sec ) m_check_update_time = tv;
+
+    // DAT落ちしていてログイン中で無い時はロードしない
+    if( ( m_status & STATUS_OLD ) && ! LOGIN::get_login2ch()->login_now() ){
+        CORE::core_set_command( "toggle_favorite_icon", m_url );
+        return;
+    }
+
+#ifdef _DEBUG
+    std::cout << "start\n";
+#endif       
+    get_nodetree()->download_dat( check_update );
 }
 
 
@@ -844,6 +892,9 @@ void ArticleBase::slot_node_updated()
 {
     assert( m_nodetree );
 
+    // 更新チェック中
+    if( m_nodetree->is_checking_update() ) return;
+
 #ifdef _DEBUG
     std::cout << "ArticleBase::slot_node_updated" << std::endl;
 #endif
@@ -851,7 +902,6 @@ void ArticleBase::slot_node_updated()
     // nodetreeから情報取得
     if( ! m_nodetree->get_subject().empty() ) set_subject( m_nodetree->get_subject() );
 
-
     // スレが更新している場合
     if( m_number_load != m_nodetree->get_res_number() ){
 
@@ -878,14 +928,9 @@ void ArticleBase::slot_load_finished()
 
     slot_node_updated();
 
-    // nodetreeから情報取得
+    // HTTPコード取得
+    int old_code = m_code;
     m_code = m_nodetree->get_code();
-    m_str_code = m_nodetree->get_str_code();
-    m_date_modified = m_nodetree->date_modified();
-    if( m_number_before_load < m_number_load ) m_number_new = m_number_load - m_number_before_load;
-    else m_number_new = 0;
-    m_number_before_load = m_number_load;
-    m_ext_err = m_nodetree->get_ext_err();
 
     // 状態更新
     int old_status = m_status;
@@ -895,6 +940,7 @@ void ArticleBase::slot_load_finished()
         if( m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND ){
             m_status &= ~STATUS_NORMAL;
             m_status |= STATUS_OLD;
+            CORE::core_set_command( "toggle_favorite_icon", m_url );
         }
 
         // 既にDAT落ち状態では無いときは通常状態にする
@@ -910,23 +956,62 @@ void ArticleBase::slot_load_finished()
     // 状態が変わっていたら情報保存
     if( old_status != m_status ) m_save_info = true;
 
+    // 更新チェック
+    if( m_nodetree->is_checking_update() ){
+
+#ifdef _DEBUG
+        std::cout << "check_update code = " << m_code << std::endl;
+#endif
+
+        // スレタブとお気に入りのアイコンを更新
+        if( m_code == HTTP_OK || m_code == HTTP_PARTIAL_CONTENT ){
+
+            show_updateicon( true );
+        }
+
+        // code と modified を戻しておく
+        m_code = old_code;
+        m_nodetree->set_date_modified( m_date_modified );
+
+        // 次のスレを更新チェック
+        CORE::get_checkupdate_manager()->pop_front();
+
+        return;
+    }
+
+    // nodetreeから情報取得
+    m_str_code = m_nodetree->get_str_code();
+    std::string m_old_modified = m_date_modified;
+    m_date_modified = m_nodetree->date_modified();
+    if( m_number_before_load < m_number_load ) m_number_new = m_number_load - m_number_before_load;
+    else m_number_new = 0;
+    m_number_before_load = m_number_load;
+    m_ext_err = m_nodetree->get_ext_err();
+
     // スレの数が0ならスレ情報はセーブしない
     if( ! m_number_load ) m_cached = false;
 
-    // スレが更新している場合はスレ情報を更新
-    else if( m_number_new ){
+    else{
 
-        struct timeval tv;
-        struct timezone tz;
-        if( gettimeofday( &tv, &tz ) == 0 ) m_access_time = tv;
+        // スレが更新している場合はスレ情報を更新
+        if( m_number_new
+            || m_date_modified != m_old_modified // ときどき modified が誤って返るときがあるので最新の値を保存しておく
+            ){
 
-        if( m_number < m_number_load ) m_number = m_number_load;
-        m_number_seen = m_number_load;
+            struct timeval tv;
+            struct timezone tz;
+            if( gettimeofday( &tv, &tz ) == 0 ) m_access_time = tv;
 
-        m_cached = true;
-        m_read_info = true;
-        m_save_info = true;
-        m_enable_load = false;
+            if( m_number < m_number_load ) m_number = m_number_load;
+            m_number_seen = m_number_load;
+
+            m_cached = true;
+            m_read_info = true;
+            m_save_info = true;
+            m_enable_load = false;
+
+            show_updateicon( false );
+        }
     }
 
 #ifdef _DEBUG
@@ -953,11 +1038,44 @@ void ArticleBase::slot_load_finished()
 
 
 
+//
+// 更新アイコン表示
+//
+// updated == true の時に表示。falseなら戻す
+//
+void ArticleBase::show_updateicon( const bool update )
+{
+#ifdef _DEBUG
+    std::cout << "ArticleBase::show_updateicon update = " << update << " status = " << m_status << std::endl;
+#endif
+
+    struct timeval tv;
+    struct timezone tz;
+    if( gettimeofday( &tv, &tz ) != 0 ) m_check_update_time = tv;
+
+    if( update ){
+
+        if( ! ( m_status & STATUS_UPDATE ) ){
+            m_status |= STATUS_UPDATE;
+            CORE::core_set_command( "toggle_article_icon", m_url);
+            CORE::core_set_command( "toggle_favorite_icon", m_url );
+        }
+    }
+    else{
+
+        // お気に入りのアイコン表示を戻す。スレタブのアイコンの方はArticleViewが戻す
+        if( m_status & STATUS_UPDATE ){
+            m_status &= ~STATUS_UPDATE;
+            CORE::core_set_command( "toggle_favorite_icon", m_url );
+        }
+    }
+}
+
 
 //
 // キャッシュ削除
 //
-void ArticleBase::delete_cache()
+void ArticleBase::delete_cache( const bool cache_only )
 {
 #ifdef _DEBUG
     std::cout << "ArticleBase::delete_cache  url = " << m_url << std::endl;
@@ -965,7 +1083,7 @@ void ArticleBase::delete_cache()
 
     if( empty() ) return;
 
-    if( m_bookmarked_thread ){
+    if( ! cache_only && m_bookmarked_thread ){
         SKELETON::MsgDiag mdiag( NULL, "「" + get_subject() + "」はブックマークされています。\n\nスレを削除しますか？"
                                   ,false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         mdiag.set_default_response( Gtk::RESPONSE_YES );
@@ -973,43 +1091,52 @@ void ArticleBase::delete_cache()
     }
 
     m_number_load = m_number_seen = m_number_before_load = 0;
+    m_cached = false;
     m_status = STATUS_UNKNOWN;
     m_date_modified.clear();
     memset( &m_access_time, 0, sizeof( struct timeval ) );
-    memset( &m_write_time, 0, sizeof( struct timeval ) );
-    m_write_time_date.clear();
+    memset( &m_check_update_time, 0, sizeof( struct timeval ) );
 
-    m_write_name.clear();
-    m_write_mail.clear();
-    m_write_fixname = false;
-    m_write_fixmail = false;
+    if( ! cache_only ){
 
-    m_vec_bookmark.clear();
-    m_list_abone_id.clear();
-    m_list_abone_name.clear();
-    m_list_abone_word.clear();
-    m_list_abone_regex.clear();
-    m_vec_abone_res.clear();
-    m_abone_transparent = false;
-    m_abone_chain = false;
-    m_cached = false;
-    m_read_info = false;
-    m_save_info = false;
-    m_enable_load = false;
-    m_bookmarked_thread = false;
+        memset( &m_write_time, 0, sizeof( struct timeval ) );
+        m_write_time_date.clear();
+
+        m_write_name.clear();
+        m_write_mail.clear();
+        m_write_fixname = false;
+        m_write_fixmail = false;
+
+        m_vec_bookmark.clear();
+        m_list_abone_id.clear();
+        m_list_abone_name.clear();
+        m_list_abone_word.clear();
+        m_list_abone_regex.clear();
+        m_vec_abone_res.clear();
+        m_abone_transparent = false;
+        m_abone_chain = false;
+        m_read_info = false;
+        m_save_info = false;
+        m_enable_load = false;
+        m_bookmarked_thread = false;
     
+        // info
+        if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_info.c_str() );
+
+        // 拡張info
+        if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_ext_info.c_str() );
+
+    }
+
     // キャッシュ
     std::string path_dat = CACHE::path_dat( m_url );
     if( CACHE::file_exists( path_dat ) == CACHE::EXIST_FILE ) unlink( path_dat.c_str() );
 
-    // info
-    if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_info.c_str() );
-
-    // 拡張info
-    if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_ext_info.c_str() );
-
     // BoardViewの行を更新
     CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
+
+    // お気に入りのアイコン表示を戻す
+    CORE::core_set_command( "toggle_favorite_icon", m_url );
 }
 
 
@@ -1029,7 +1156,7 @@ bool ArticleBase::save_dat( const std::string& path_to )
     std::string name = MISC::get_filename( path_to );
     if( name.empty() ) name = MISC::get_filename( m_url );    
 
-    std::string save_to = CACHE::open_save_diag( NULL, CACHE::path_dat( m_url ), dir + name );
+    std::string save_to = CACHE::copy_file( NULL, CACHE::path_dat( m_url ), dir + name, CACHE::FILE_TYPE_DAT );
 
     if( ! save_to.empty() ){
         SESSION::set_dir_dat_save( MISC::get_dir( save_to ) );
@@ -1144,6 +1271,7 @@ void ArticleBase::read_info()
         m_status = STATUS_UNKNOWN;
         GET_INFOVALUE( str_tmp, "status = " );
         if( ! str_tmp.empty() ) m_status = atoi( str_tmp.c_str() );
+        m_status &= ~STATUS_UPDATE; // 更新可能状態解除
 
         // あぼーん ID
         GET_INFOVALUE( str_tmp, "aboneid = " );
@@ -1187,7 +1315,7 @@ void ArticleBase::read_info()
         if( ! str_tmp.empty() ) m_abone_chain = atoi( str_tmp.c_str() );
 
         // レス番号あぼーん
-        m_abone_chain = false;
+        m_vec_abone_res.clear();
         GET_INFOVALUE( str_tmp, "aboneres = " );
         if( ! str_tmp.empty() ){
 
