@@ -27,8 +27,10 @@
 
 #include <sstream>
 
-#define SIZE_OF_RAWDATA ( 2 * 1024 * 1024 )
-
+enum
+{
+    SIZE_OF_RAWDATA = 2 * 1024 * 1024
+};
 
 using namespace DBTREE;
 
@@ -39,13 +41,18 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     , m_root( root )
     , m_path_board( path_board )
     , m_name( name )
+    , m_samba_sec( 0 )
+    , m_number_max_res( 0 )
     , m_rawdata( 0 )
     , m_read_info( 0 )
+    , m_append_articles( false )
     , m_article_null( 0 )
 {
     clear();
     clear_load_data();
 
+    memset( &m_write_time, 0, sizeof( struct timeval ) );
+
     // 板情報はクラスが作られた時点ではまだ読まない
     // BoardBase::read_info() の説明を見ること
 }
@@ -153,6 +160,13 @@ const int BoardBase::get_proxy_port_w()
 }
 
 
+// ローカルルール
+const std::string BoardBase::localrule()
+{
+    return "利用できません";
+}
+
+
 // setting.txt
 const std::string BoardBase::settingtxt()
 {
@@ -210,6 +224,53 @@ ArticleBase* BoardBase::append_article( const std::string& id, bool cached )
 }
 
 
+//
+// 書き込み時間更新
+//
+void BoardBase::update_writetime()
+{
+    struct timeval tv;
+    struct timezone tz;
+    if( gettimeofday( &tv, &tz ) == 0 ){
+
+        m_write_time = tv;
+
+#ifdef _DEBUG
+        std::cout << "BoardBase::update_writetime : " << m_write_time.tv_sec << std::endl;
+#endif
+    }
+}
+
+
+//
+// 経過時間(秒)
+//
+const time_t BoardBase::get_write_pass()
+{
+    time_t ret = 0;
+    struct timeval tv;
+    struct timezone tz;
+
+    if( m_write_time.tv_sec && gettimeofday( &tv, &tz ) == 0 ) ret = MAX( 0, tv.tv_sec - m_write_time.tv_sec );
+
+    return ret;
+}
+
+
+//
+// 書き込み可能までの残り秒
+//
+time_t BoardBase::get_write_leftsec()
+{
+    const time_t mrg = 2;
+
+    if( ! m_samba_sec ) return 0;
+    if( ! get_write_pass() ) return 0;
+
+    return MAX( 0, m_samba_sec + mrg - get_write_pass() );
+}
+
+
 
 //
 // 板情報の取得
@@ -232,11 +293,8 @@ void BoardBase::read_info()
         // 板の情報ファイル読み込み
         read_board_info();
 
-        // キャッシュにあるレスをデータベースに登録
-        append_all_article_in_cache();
-
-        // キャッシュからSETTING.TXT のロード
-        load_setting();
+        // キャッシュからローカルルールとSETTING.TXT のロード
+        load_rule_setting();
     }
 }
 
@@ -515,6 +573,9 @@ ArticleBase* BoardBase::get_article( const std::string id )
 {
     if( id.empty() ) return get_article_null();
 
+    // キャッシュにあるレスをデータベースに登録
+    append_all_article_in_cache();
+
     // 線形リストなので遅い
     // TODO : ハッシュにする
     std::list< ArticleBase* >::iterator it;
@@ -555,7 +616,7 @@ ArticleBase* BoardBase::get_article_create( const std::string id )
 
         // データベースに無いので新規登録
         //
-        // なおRoot::get_board()　経由で呼ばれる BoardBase::read_info() でキャッシュにある
+        // なおget_article()でキャッシュにある
         // スレは全てDBに登録されているので DBに無いということはキャッシュにも無いということ。
         // よって append_article()に  cached = false　をパラメータとして渡す
 
@@ -635,6 +696,7 @@ void BoardBase::download_subject()
     clear();
     m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
     m_read_url_boardbase = false;
+    m_load_rule_setting = false;
 
     // オフライン
     if( ! SESSION::is_online() ){
@@ -648,6 +710,8 @@ void BoardBase::download_subject()
 
     // オンライン
 
+    m_load_rule_setting = true;
+
     // subject.txtのキャッシュが無かったら modified をリセット
     std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
     if( CACHE::file_exists( path_subject ) != CACHE::EXIST_FILE ) set_date_modified( std::string() );
@@ -693,8 +757,8 @@ void BoardBase::receive_data( const char* data, size_t size )
 //
 void BoardBase::receive_finish()
 {
-    // 別スレッドでSETTING.TXT のダウンロード開始
-    if( SESSION::is_online() ) download_setting();
+    // 別スレッドでローカルルールとSETTING.TXT のダウンロード開始
+    if( m_load_rule_setting ) download_rule_setting();
 
     m_list_subject.clear();
 
@@ -707,7 +771,7 @@ void BoardBase::receive_finish()
     std::cout << "size = " << m_lng_rawdata << std::endl;
 #endif
 
-    // 移転チェック
+    // url_boardbase をロードして移転が起きたかチェック
     if( m_read_url_boardbase ){
 
 #ifdef _DEBUG
@@ -727,17 +791,22 @@ void BoardBase::receive_finish()
             if( regex.exec( query, m_rawdata ) ){
 
                 std::string new_url = regex.str( 1 );
-                std::string msg = new_url + " に移転しました。\n\nデータベースを更新しますか？";
+                std::string msg = "「" + get_name() + "」は\n\n" + new_url + " に移転しました。\n\nデータベースを更新しますか？";
 
-                SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-                mdiag.set_default_response( Gtk::RESPONSE_OK );
-                if( mdiag.run() == Gtk::RESPONSE_OK ){
+                SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+                mdiag.set_default_response( Gtk::RESPONSE_YES );
+                if( mdiag.run() == Gtk::RESPONSE_YES ){
 
                     DBTREE::update_board( new_url, get_name() );
                     CORE::core_set_command( "open_board", url_subject() );
                 }
             }
         }
+        else{
+            SKELETON::MsgDiag mdiag( NULL, "移転しました\n\n板リストを更新しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            mdiag.set_default_response( Gtk::RESPONSE_YES );
+            if( mdiag.run() == Gtk::RESPONSE_YES ) CORE::core_set_command( "reload_bbsmenu" );
+        }
 
         clear();
         return;
@@ -750,14 +819,13 @@ void BoardBase::receive_finish()
 
         m_lng_rawdata = 0;
 
-        // 移転した場合bbsmenuを更新
+        // リダイレクトの場合は移転確認
         if( get_code() == HTTP_REDIRECT ){
 
-            SKELETON::MsgDiag mdiag( NULL, "移転しました\n\n板リストを更新しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
-            mdiag.set_default_response( Gtk::RESPONSE_OK );
-            if( mdiag.run() == Gtk::RESPONSE_OK ) CORE::core_set_command( "reload_bbsmenu" );
-
             set_date_modified( std::string() );
+
+            if( start_checkking_if_board_moved() ) return;
+
             CORE::core_set_command( "update_board", url_subject() );
             clear();
             return;
@@ -793,23 +861,7 @@ void BoardBase::receive_finish()
 
         // 移転した可能性があるので url_boardbase をロードして解析
         if( SESSION::is_online() && get_code() == HTTP_OK ){
-
-#ifdef _DEBUG
-            std::cout << "reload " << url_boardbase() << std::endl;
-#endif
-            JDLIB::LOADERDATA data;    
-            data.url = url_boardbase();
-            data.agent = CONFIG::get_agent_for_data();
-            if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
-            else data.host_proxy = std::string();
-            data.port_proxy = CONFIG::get_proxy_port_for_data();
-            data.size_buf = CONFIG::get_loader_bufsize();
-            data.timeout = CONFIG::get_loader_timeout_img();
-
-            if( start_load( data ) ){
-                m_read_url_boardbase = true;
-                return;
-            }
+            if( start_checkking_if_board_moved() ) return;
         }
 
         CORE::core_set_command( "update_board", url_subject() );
@@ -827,6 +879,9 @@ void BoardBase::receive_finish()
     // データベース更新
     // subject.txtを解析して現行スレだけリスト(m_list_subject)に加える
 
+    // キャッシュにあるレスをデータベースに登録
+    append_all_article_in_cache();
+
     // 一度全てのarticleをdat落ち状態にして subject.txt に
     // 含まれているものだけ parse_subject()の中で通常状態にする
     std::list< ArticleBase* >::iterator it;
@@ -862,7 +917,7 @@ void BoardBase::receive_finish()
                     // info 読み込み
                     // TODO : 数が多いとboardビューを開くまで時間がかかるのをなんとかする
 #ifdef _DEBUG
-                    std::cout << "read article_info << " << ( *it )->get_url() << std::endl;
+                    std::cout << "read article_info : " << ( *it )->get_url() << std::endl;
 #endif                
                     ( *it )->read_info();
 
@@ -876,7 +931,7 @@ void BoardBase::receive_finish()
                         ( *it )->save_info( true );
                     }
 
-                    if( ! get_abone_thread( *it ) ) m_list_subject.push_back( *it );
+                    if( ! is_abone_thread( *it ) ) m_list_subject.push_back( *it );
                 }
             }
         }
@@ -928,6 +983,34 @@ void BoardBase::receive_finish()
 }
 
 
+//
+// url_boardbase をロードして移転したかどうか解析開始
+//
+// 移転した場合は window.location.href が含まれるテキストがサーバから送られてくる
+//
+bool BoardBase::start_checkking_if_board_moved()
+{
+#ifdef _DEBUG
+    std::cout << "BoardBase::start_checkking_if_board_moved " << url_boardbase() << std::endl;
+#endif
+
+    JDLIB::LOADERDATA data;    
+    data.url = url_boardbase();
+    data.agent = CONFIG::get_agent_for_data();
+    if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
+    else data.host_proxy = std::string();
+    data.port_proxy = CONFIG::get_proxy_port_for_data();
+    data.size_buf = CONFIG::get_loader_bufsize();
+    data.timeout = CONFIG::get_loader_timeout_img();
+
+    if( start_load( data ) ){
+        m_read_url_boardbase = true;
+        return true;
+    }
+
+    return false;
+}
+
 
 //
 // キャッシュのディレクトリ内にあるスレのファイル名のリストを取得
@@ -964,6 +1047,9 @@ std::list< std::string > BoardBase::get_filelist_in_cache()
 //
 void BoardBase::append_all_article_in_cache()
 {
+    if( m_append_articles ) return;
+    m_append_articles = true;
+
 #ifdef _DEBUG
     std::cout << "BoardBase::append_all_article_in_cache\n";
 #endif
@@ -1003,19 +1089,28 @@ void BoardBase::update_abone_all_article()
 //
 // スレあぼーん判定
 //
-const bool BoardBase::get_abone_thread( ArticleBase* article )
+const bool BoardBase::is_abone_thread( ArticleBase* article )
 {
     if( ! article ) return false;
+    if( article->empty() ) return false;
 
-    bool check_thread = ! m_list_abone_thread.empty();
-    bool check_word = ! m_list_abone_word_thread.empty();
-    bool check_regex = ! m_list_abone_regex_thread.empty();
-    bool check_word_global = ! CONFIG::get_list_abone_word_thread().empty();
-    bool check_regex_global = ! CONFIG::get_list_abone_regex_thread().empty();
+    const int check_number = article->get_number_load() ? 0: ( m_abone_number_thread ? m_abone_number_thread : get_abone_number_global() );
+    const int check_hour = article->get_number_load() ? 0: ( m_abone_hour_thread ? m_abone_hour_thread : CONFIG::get_abone_hour_thread() );
+    const bool check_thread = ! m_list_abone_thread.empty();
+    const bool check_word = ! m_list_abone_word_thread.empty();
+    const bool check_regex = ! m_list_abone_regex_thread.empty();
+    const bool check_word_global = ! CONFIG::get_list_abone_word_thread().empty();
+    const bool check_regex_global = ! CONFIG::get_list_abone_regex_thread().empty();
 
-    if( !check_thread && !check_word && !check_regex && !check_word_global && !check_regex_global ) return false;
+    if( !check_number && !check_hour && !check_thread && !check_word && !check_regex && !check_word_global && !check_regex_global ) return false;
 
     JDLIB::Regex regex;
+
+    // レスの数であぼーん
+    if( check_number ) if( article->get_number() >= check_number ) return true;
+
+    // スレ立てからの時間であぼーん
+    if( check_hour ) if( article->get_hour() >= check_hour ) return true;
     
     // スレあぼーん
     if( check_thread ){
@@ -1083,11 +1178,75 @@ void BoardBase::update_abone_thread()
 
 
 
+//
+// あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
+//
+void BoardBase::reset_abone( std::list< std::string >& ids, std::list< std::string >& names, std::list< std::string >& words, std::list< std::string >& regexs )
+{
+    if( empty() ) return;
+
+    // 前後の空白と空白行を除く
+
+    m_list_abone_id = MISC::remove_space_from_list( ids );
+    m_list_abone_id = MISC::remove_nullline_from_list( m_list_abone_id );
+
+    m_list_abone_name = MISC::remove_space_from_list( names );
+    m_list_abone_name = MISC::remove_nullline_from_list( m_list_abone_name );
+
+    m_list_abone_word = MISC::remove_space_from_list( words );
+    m_list_abone_word = MISC::remove_nullline_from_list( m_list_abone_word );
+
+    m_list_abone_regex = MISC::remove_space_from_list( regexs );
+    m_list_abone_regex = MISC::remove_nullline_from_list( m_list_abone_regex );
+
+    update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+
+// あぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう)
+void BoardBase::add_abone_id( const std::string& id )
+{
+    if( empty() ) return;
+    if( id.empty() ) return;
+
+    std::string id_tmp = id.substr( strlen( PROTO_ID ) );
+
+    m_list_abone_id.push_back( id_tmp );
+
+    update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+void BoardBase::add_abone_name( const std::string& name )
+{
+    if( empty() ) return;
+    if( name.empty() ) return;
+
+    m_list_abone_name.push_back( name );
+
+    update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+void BoardBase::add_abone_word( const std::string& word )
+{
+    if( empty() ) return;
+    if( word.empty() ) return;
+
+    m_list_abone_word.push_back( word );
+
+    update_abone_all_article();
+    CORE::core_set_command( "relayout_all_article" );
+}
+
+
 //
 // あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
 //
 void BoardBase::reset_abone_thread( std::list< std::string >& threads,
-                                    std::list< std::string >& words, std::list< std::string >& regexs )
+                                    std::list< std::string >& words, std::list< std::string >& regexs,
+                                    const int number, const int hour )
 {
     if( empty() ) return;
 
@@ -1106,6 +1265,9 @@ void BoardBase::reset_abone_thread( std::list< std::string >& threads,
     m_list_abone_regex_thread = MISC::remove_space_from_list( regexs );
     m_list_abone_regex_thread = MISC::remove_nullline_from_list( m_list_abone_regex_thread );
 
+    m_abone_number_thread = number;
+    m_abone_hour_thread = hour;
+
     update_abone_thread();
 }
 
@@ -1128,6 +1290,10 @@ std::list< std::string > BoardBase::search_cache( const std::string& query,
 
     if( empty() ) return list_out;
 
+    // キャッシュにあるレスをデータベースに登録
+    append_all_article_in_cache();
+    if( m_list_article.size() == 0 ) return list_out;
+
     std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
     std::list< std::string > list_query = MISC::split_line( query_local );
 
@@ -1197,6 +1363,9 @@ void BoardBase::read_board_info()
     std::string modified = cf.get_option( "modified", "" );
     set_date_modified( modified );
 
+    m_modified_localrule = cf.get_option( "modified_localrule", "" );
+    m_modified_setting = cf.get_option( "modified_setting", "" );
+
     m_view_sort_column = cf.get_option( "view_sort_column", -1 );
     m_view_sort_mode = cf.get_option( "view_sort_mode", 0 );
     m_view_sort_pre_column = cf.get_option( "view_sort_pre_column", -1 );
@@ -1204,8 +1373,26 @@ void BoardBase::read_board_info()
 
     m_check_noname = cf.get_option( "check_noname", false );
 
+    std::string str_tmp;
+
+    // あぼーん id は再起動ごとにリセット
+//    str_tmp = cf.get_option( "aboneid", "" );
+//    if( ! str_tmp.empty() ) m_list_abone_id = MISC::strtolist( str_tmp );
+
+    // あぼーん name
+    str_tmp = cf.get_option( "abonename", "" );
+    if( ! str_tmp.empty() ) m_list_abone_name = MISC::strtolist( str_tmp );
+
+    // あぼーん word
+    str_tmp = cf.get_option( "aboneword", "" );
+    if( ! str_tmp.empty() ) m_list_abone_word = MISC::strtolist( str_tmp );
+
+    // あぼーん regex
+    str_tmp = cf.get_option( "aboneregex", "" );
+    if( ! str_tmp.empty() ) m_list_abone_regex = MISC::strtolist( str_tmp );
+
     // スレ あぼーん
-    std::string str_tmp = cf.get_option( "abonethread", "" );
+    str_tmp = cf.get_option( "abonethread", "" );
     if( ! str_tmp.empty() ) m_list_abone_thread = MISC::strtolist( str_tmp );
 
     // スレ あぼーん word
@@ -1216,6 +1403,12 @@ void BoardBase::read_board_info()
     str_tmp = cf.get_option( "aboneregexthread", "" );
     if( ! str_tmp.empty() ) m_list_abone_regex_thread = MISC::strtolist( str_tmp );
 
+    // レス数であぼーん
+    m_abone_number_thread = cf.get_option( "abonenumberthread", 0 );
+
+    // スレ立てからの経過時間であぼーん
+    m_abone_hour_thread = cf.get_option( "abonehourthread", 0 );
+
     // ローカルプロキシ
     m_mode_local_proxy = cf.get_option( "mode_local_proxy", 0 );
     m_local_proxy = cf.get_option( "local_proxy", "" );
@@ -1229,6 +1422,9 @@ void BoardBase::read_board_info()
     m_write_name = cf.get_option( "write_name", "" );
     m_write_mail = cf.get_option( "write_mail", "" );
 
+    // samba24
+    m_samba_sec = cf.get_option( "samba_sec", 0 );
+
 #ifdef _DEBUG
     std::cout << "modified = " << date_modified() << std::endl;
 #endif
@@ -1263,21 +1459,39 @@ void BoardBase::save_jdboard_info()
 #endif
 
     // あぼーん情報
-    std::string str_abone = MISC::listtostr( m_list_abone_thread );
-    std::string str_abone_word = MISC::listtostr( m_list_abone_word_thread );
-    std::string str_abone_regex = MISC::listtostr( m_list_abone_regex_thread );
+    std::string str_abone_id = MISC::listtostr( m_list_abone_id );
+    std::string str_abone_name = MISC::listtostr( m_list_abone_name );
+    std::string str_abone_word = MISC::listtostr( m_list_abone_word );
+    std::string str_abone_regex = MISC::listtostr( m_list_abone_regex );
+
+    // スレあぼーん情報
+    std::string str_abone_thread = MISC::listtostr( m_list_abone_thread );
+    std::string str_abone_word_thread = MISC::listtostr( m_list_abone_word_thread );
+    std::string str_abone_regex_thread = MISC::listtostr( m_list_abone_regex_thread );
     
     std::ostringstream sstr;
     sstr << "modified = " << date_modified() << std::endl
+         << "modified_localrule = " << m_modified_localrule << std::endl
+         << "modified_setting = " << m_modified_setting << std::endl
          << "view_sort_column = " << m_view_sort_column << std::endl
          << "view_sort_mode = " << m_view_sort_mode << std::endl
          << "view_sort_pre_column = " << m_view_sort_pre_column << std::endl
          << "view_sort_pre_mode = " << m_view_sort_pre_mode << std::endl
          << "check_noname = " << m_check_noname << std::endl
-         << "abonethread = " << str_abone << std::endl
-         << "abonewordthread = " << str_abone_word << std::endl
-         << "aboneregexthread = " << str_abone_regex << std::endl
+
+    // IDは再起動ごとにリセット
+//         << "aboneid = " << str_abone_id << std::endl
+         << "abonename = " << str_abone_name << std::endl
+         << "aboneword = " << str_abone_word << std::endl
+         << "aboneregex = " << str_abone_regex << std::endl
+
+         << "abonethread = " << str_abone_thread << std::endl
+         << "abonewordthread = " << str_abone_word_thread << std::endl
+         << "aboneregexthread = " << str_abone_regex_thread << std::endl
+         << "abonenumberthread = " << m_abone_number_thread << std::endl
+         << "abonehourthread = " << m_abone_hour_thread << std::endl
          << "mode_local_proxy = " << m_mode_local_proxy << std::endl
+
          << "local_proxy = " << m_local_proxy << std::endl
          << "local_proxy_port = " << m_local_proxy_port << std::endl
          << "mode_local_proxy_w = " << m_mode_local_proxy_w << std::endl
@@ -1285,6 +1499,7 @@ void BoardBase::save_jdboard_info()
          << "local_proxy_port_w = " << m_local_proxy_port_w << std::endl
          << "write_name = " << m_write_name << std::endl
          << "write_mail = " << m_write_mail << std::endl
+         << "samba_sec = " << m_samba_sec << std::endl
     ;
 
     CACHE::save_rawdata( path_info, sstr.str() );
