@@ -61,7 +61,12 @@ ArticleBase* BoardJBBS::append_article( const std::string& id, bool cached )
     if( empty() ) return get_article_null();
 
     ArticleBase* article = new DBTREE::ArticleJBBS( url_datbase(), id, cached );
-    if( article ) get_list_article().push_back( article );
+    if( article ){
+        get_list_article().push_back( article );
+
+        // 最大レス数セット
+        article->set_number_max( get_number_max_res() );
+    }
     else return get_article_null();
 
     return article;
@@ -217,8 +222,7 @@ void BoardJBBS::parse_subject( const char* str_subject_txt )
 
         // DBにないなら新規に article クラスを追加
         //
-        // なおRoot::get_board()　経由で void BoardBase::read_info()及び
-        // BoardBase::read_all_article_info() が既に呼ばれているので
+        // なお BoardBase::receive_finish() のなかで append_all_article_in_cache() が既に呼び出されているため
         // DBに無いということはキャッシュにも無いということ。よって append_article()で  cached = false
 
         if( article->empty() ) article = append_article( id, false );
