@@ -27,10 +27,8 @@ namespace IMAGE
 
         std::string m_errmsg; // エラーメッセージ
 
-        bool m_ready;      // show_image()が呼ばれたらtrueにセット
+        bool m_ready; // 画像がsetされた
 
-        int m_width_org;
-        int m_height_org;
         int m_width;
         int m_height;
 
@@ -40,12 +38,11 @@ namespace IMAGE
         void set_errmsg( const std::string& errmsg ){ m_errmsg = errmsg; }
         void set_ready( bool ready ){ m_ready = ready; }
 
-        void set_width_org( int width_org ){ m_width_org = width_org; }
-        void set_height_org( int height_org ){ m_height_org = height_org; }
-        void set_width( int width ){ m_width = width; }
-        void set_height( int height ){ m_height = height; }
+        void set_width( const int width );
+        void set_height( const int height );
 
-        void set_image(  Glib::RefPtr< Gdk::Pixbuf >& pixbuf, bool mosaic, bool do_scale, double scale );
+        void set_image();
+        void set_mosaic( Glib::RefPtr< Gdk::Pixbuf > pixbuf );
 
       public:
 
@@ -55,8 +52,6 @@ namespace IMAGE
         const std::string& get_url() const{ return m_url;}
         const std::string& get_errmsg() const{ return m_errmsg;}        
         const bool is_ready() const { return m_ready; }
-        const int get_width_org() const { return m_width_org; }
-        const int get_height_org() const { return m_height_org; }
         const int get_width() const { return m_width; }
         const int get_height() const { return m_height; }
 
