@@ -30,7 +30,10 @@
 #define MIN( a, b ) ( a < b ? a : b )
 #endif
 
-#define IMGWIN_REDRAWTIME 250 // msec
+enum
+{
+    IMGWIN_REDRAWTIME = 250 // msec
+};
 
 using namespace IMAGE;
 
@@ -47,6 +50,9 @@ ImageViewMain::ImageViewMain( const std::string& url )
     std::cout << "ImageViewMain::ImageViewMain : " << get_url() << std::endl;
 #endif
 
+    // コントロールモード設定
+    get_control().add_mode( CONTROL::MODE_IMAGEVIEW );
+
     // スクロールウィンドウを作ってEventBoxを貼る
     m_scrwin = Gtk::manage( new Gtk::ScrolledWindow() );
     assert( m_scrwin );
@@ -152,12 +158,17 @@ void ImageViewMain::clock_in()
 //
 void ImageViewMain::show_instruct_diag()
 {
+    const int mrg = 16;
+
     IMAGE::get_admin()->set_command_immediately( "disable_fold_win" );
 
     SKELETON::MsgDiag mdiag( NULL, 
-        "画像ビューからスレ一ビューに戻る方法として\n\n(1) マウスジェスチャを使う( 右ボタンを押しながら左にドラッグして離す )\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレビューアイコンを押す\n\n(5) 表示メニューからスレビューを選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。" );
-    Gtk::CheckButton chkbutton( "今後表示しない" );
-    mdiag.get_vbox()->pack_start( chkbutton, Gtk::PACK_SHRINK );
+        "画像ビューからスレビューに戻る方法として\n\n(1) マウスジェスチャを使う\n(マウス右ボタンを押しながら左または下にドラッグして右ボタンを離す)\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレビューアイコンを押す\n\n(5) 表示メニューからスレビューを選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。" );
+    Gtk::HBox hbox;
+    Gtk::CheckButton chkbutton( "今後表示しない(_D)", true );
+    hbox.pack_start( chkbutton, Gtk::PACK_EXPAND_WIDGET, mrg );
+//    chkbutton.set_alignment( 1.0, 0.0 );
+    mdiag.get_vbox()->pack_start( hbox, Gtk::PACK_SHRINK );
     mdiag.set_title( "ヒント" );
     mdiag.show_all_children();
     mdiag.run();
@@ -276,8 +287,8 @@ void ImageViewMain::show_status()
         if( get_imagearea() ){
 
             std::stringstream ss;
-            ss << get_imagearea()->get_width_org() << " x " << get_imagearea()->get_height_org();
-            if( get_imagearea()->get_width_org() )
+            ss << get_img()->get_width() << " x " << get_img()->get_height();
+            if( get_img()->get_width() )
                 ss << " (" << get_img()->get_size() << " %)";
             ss << " " << get_img()->total_length()/1024 << " kb ";
             if( get_img()->is_protected() ) ss << " キャッシュ保護されています";
@@ -362,7 +373,7 @@ bool ImageViewMain::slot_motion_notify( GdkEventMotion* event )
     if( m_scrwin ){
 
         GdkEventButton event_button;
-        get_control().get_eventbutton( CONTROL::ClickButton, event_button );
+        get_control().get_eventbutton( CONTROL::ScrollImageButton, event_button );
 
 #ifdef _DEBUG
         std::cout << "state = " << event->state << " / " << GDK_BUTTON1_MASK << " button = " << event_button.button << std::endl;
