@@ -39,6 +39,7 @@ namespace IMAGE
         bool m_loading;
         Gtk::EventBox m_event;
         bool m_dblclick;
+        bool m_under_mouse;
 
         bool m_enable_menuslot;
 
@@ -59,6 +60,8 @@ namespace IMAGE
         ImageViewBase( const std::string& url, const std::string& arg1 = std::string(), const std::string& arg2 = std::string() );
         virtual ~ImageViewBase();
 
+        const bool is_under_mouse() const { return m_under_mouse; }
+
         // コマンド
         virtual bool set_command( const std::string& command, const std::string& arg = std::string() );
 
@@ -69,6 +72,7 @@ namespace IMAGE
         virtual void close_view();
         virtual void delete_view();
         virtual void operate_view( const int& control );
+        virtual void show_preference();
 
       protected:
 
@@ -82,7 +86,8 @@ namespace IMAGE
         virtual bool slot_motion_notify( GdkEventMotion* event );
         bool slot_key_press( GdkEventKey* event );
         virtual bool slot_scroll_event( GdkEventScroll* event );
-
+        bool slot_enter_notify_event( GdkEventCrossing* event );
+        bool slot_leave_notify_event( GdkEventCrossing* event );
 
       private:
 
@@ -96,10 +101,12 @@ namespace IMAGE
         void slot_move_tail();
         void slot_reload_force();
         void slot_cancel_mosaic();
+        void slot_show_large_img();
         void slot_fit_win();
         void slot_zoom_in();
         void slot_zoom_out();
         void slot_resize_image( int size );
+        void slot_lock();
         void slot_open_browser();
         void slot_open_ref();
         void slot_copy_url();
@@ -107,11 +114,11 @@ namespace IMAGE
         void slot_save_all();
         void slot_favorite();
         void slot_toggle_protectimage();
+        void slot_abone_img();
         void slot_close_other_views();
         void slot_close_left_views();
         void slot_close_right_views();
         void slot_close_all_views();
-        void slot_preference();
     };
 
 }
