@@ -10,6 +10,7 @@
 
 #include "jdlib/miscmsg.h"
 #include "jdlib/miscutil.h"
+#include "jdlib/ssl.h"
 
 #include <signal.h>
 #include <string>
@@ -76,9 +77,7 @@ int lock_jd()
     }
 
     snprintf( str_pid, 256, "%d", pid );
-    if( ! CACHE::save_rawdata( path, str_pid, strlen( str_pid ) ) ){
-        MISC::ERRMSG( "can't open " + path );
-    }
+    CACHE::save_rawdata( path, str_pid, strlen( str_pid ) );
 
     return LOCK_OK;
 }
@@ -115,10 +114,10 @@ void restore_bkup()
 
         Gtk::MessageDialog* mdiag
         = new Gtk::MessageDialog( "前回の起動時に正しくJDが終了されませんでした。\n\n板リストとお気に入りをバックアップファイルから復元しますか？\nキャンセルを押すとバックアップファイルを削除します。",
-                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         int ret = mdiag->run();
         delete mdiag;
-        if( ret == Gtk::RESPONSE_OK ){
+        if( ret == Gtk::RESPONSE_YES ){
 
             if( bkup_main ){
                 rename( path_main.c_str(), path_main_old.c_str() );
@@ -360,6 +359,16 @@ int main( int argc, char **argv )
         exit( 1 );
     }
 
+    GMemVTable vtable;
+    vtable = *glib_mem_profiler_table;
+    vtable.malloc = malloc;
+    vtable.realloc = realloc;
+    vtable.free = free;
+    vtable.calloc = calloc;
+    vtable.try_malloc = malloc;
+    vtable.try_realloc = realloc;
+    g_mem_set_vtable( &vtable );
+
     Gtk::Main m( &argc, &argv );
 
     // XSMPによるセッション管理
@@ -388,21 +397,38 @@ int main( int argc, char **argv )
     else MISC::ERRMSG( "failed to connect to gnome session manager" );
 #endif
 
+    JDLIB::init_ssl();
+
     // 全体設定ロード
     bool init = !( CONFIG::load_conf() );
 
-    // 初回起動時にルートを作る
-    if( init ) CACHE::mkdir_root();
+    if( init ){
+
+        // 設定ファイルが読み込めないときに存在するか確認
+        int exists = CACHE::file_exists( CACHE::path_conf() );
+        if( exists == CACHE::EXIST_FILE || exists == CACHE::EXIST_DIR ){
+
+            std::string msg = "JDの設定ファイル(" + CACHE::path_conf() + ")は存在しますが読み込むことが出来ませんでした。\n\n起動しますか？";
+            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( msg,
+                                                                false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            int ret = mdiag->run();
+            delete mdiag;
+            if( ret != Gtk::RESPONSE_YES ) return 0;
+        }
+
+        // 初回起動時にルートを作る
+        CACHE::mkdir_root();
+    }
 
     // ロック
     int lock = lock_jd();
     if( lock == LOCK_ALIVE ){
 
         Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
-                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         int ret = mdiag->run();
         delete mdiag;
-        if( ret != Gtk::RESPONSE_OK ) return 0;
+        if( ret != Gtk::RESPONSE_YES ) return 0;
 
         unlock_jd();
         lock_jd();
@@ -410,12 +436,12 @@ int main( int argc, char **argv )
     else if( lock == LOCK_EXIST ){ 
 
         Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "前回起動時にJDが異常終了しました。\n\nロックファイルを削除して起動しますか？",
-                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
 
-        mdiag->set_default_response( Gtk::RESPONSE_OK );
+        mdiag->set_default_response( Gtk::RESPONSE_YES );
         int ret = mdiag->run();
         delete mdiag;
-        if( ret != Gtk::RESPONSE_OK ) return 0;
+        if( ret != Gtk::RESPONSE_YES ) return 0;
 
         unlock_jd();
         lock_jd();
@@ -437,6 +463,8 @@ int main( int argc, char **argv )
     xsmp_session_end( &xsmpdata );
 #endif
 
+    JDLIB::deinit_ssl();
+
     // ロック解除
     unlock_jd();
 
