@@ -23,7 +23,12 @@ namespace CORE
         PREFDIAG_GLOBALABONETHREAD,
         PREFDIAG_GLOBALABONE,
         PREFDIAG_FONTCOLOR,
+        PREFDIAG_MAINITEM,
+        PREFDIAG_SIDEBARITEM,
         PREFDIAG_BOARDITEM,
+        PREFDIAG_BOARDITEMCOLUM,
+        PREFDIAG_ARTICLEITEM,
+        PREFDIAG_MSGITEM,
 
         PREFDIAG_DELIMG,
 
