@@ -15,9 +15,15 @@
 
 #include <sstream>
 
+bool booting = true;
+bool quitting = false;
+
 int mode_pane;
 bool mode_online;
 bool mode_login2ch;
+bool mode_loginbe;
+
+std::string distribution;
 
 int win_manager;
 
@@ -42,7 +48,23 @@ std::list< bool > article_locked;
 std::list< std::string > image_urls;
 std::list< bool > image_locked;
 
-std::string items_board;
+std::string items_sidebar_str;
+std::vector< int > items_sidebar;
+
+std::string items_main_toolbar_str;
+std::vector< int > items_main_toolbar;
+
+std::string items_article_toolbar_str;
+std::vector< int > items_article_toolbar;
+
+std::string items_board_toolbar_str;
+std::vector< int > items_board_toolbar;
+
+std::string items_board_str;
+std::vector< int > items_board;
+
+std::string items_msg_toolbar_str;
+std::vector< int > items_msg_toolbar;
 
 int board_col_mark;
 int board_col_id;
@@ -117,9 +139,62 @@ std::string dir_draft;
 bool popupmenu_shown;
 
 
+
 /////////////////////////////////////
 
 
+// 項目名 -> 番号変換
+std::vector< int > parse_items( const std::string& items_str )
+{
+    std::vector< int > items;
+    std::list< std::string > list_order = MISC::split_line( items_str );
+    std::list< std::string >::iterator it = list_order.begin();
+    for( ; it != list_order.end(); ++it ){
+
+        if( *it == ITEM_NAME_BBSLISTVIEW ) items.push_back(ITEM_BBSLISTVIEW );
+        if( *it == ITEM_NAME_FAVORITEVIEW ) items.push_back(ITEM_FAVORITEVIEW );
+        if( *it == ITEM_NAME_BOARDVIEW ) items.push_back(ITEM_BOARDVIEW );
+        if( *it == ITEM_NAME_ARTICLEVIEW ) items.push_back(ITEM_ARTICLEVIEW );
+        if( *it == ITEM_NAME_IMAGEVIEW ) items.push_back(ITEM_IMAGEVIEW );
+        if( *it == ITEM_NAME_URL ) items.push_back(ITEM_URL );
+        if( *it == ITEM_NAME_GO ) items.push_back(ITEM_GO );
+        if( *it == ITEM_NAME_SEPARATOR ) items.push_back(ITEM_SEPARATOR );
+
+        if( *it == ITEM_NAME_MARK ) items.push_back(ITEM_MARK );
+        if( *it == ITEM_NAME_ID ) items.push_back(ITEM_ID );
+        if( *it == ITEM_NAME_NAME ) items.push_back(ITEM_NAME );
+        if( *it == ITEM_NAME_RES ) items.push_back(ITEM_RES );
+        if( *it == ITEM_NAME_LOAD ) items.push_back(ITEM_LOAD );
+        if( *it == ITEM_NAME_NEW ) items.push_back(ITEM_NEW );
+        if( *it == ITEM_NAME_SINCE ) items.push_back(ITEM_SINCE );
+        if( *it == ITEM_NAME_LASTWRITE ) items.push_back(ITEM_LASTWRITE );
+        if( *it == ITEM_NAME_SPEED ) items.push_back(ITEM_SPEED );
+
+        if( *it == ITEM_NAME_WRITEMSG ) items.push_back( ITEM_WRITEMSG );
+        if( *it == ITEM_NAME_OPENBOARD ) items.push_back(ITEM_OPENBOARD );
+        if( *it == ITEM_NAME_SEARCH ) items.push_back(ITEM_SEARCH );
+        if( *it == ITEM_NAME_RELOAD ) items.push_back( ITEM_RELOAD );
+        if( *it == ITEM_NAME_STOPLOADING ) items.push_back( ITEM_STOPLOADING );
+        if( *it == ITEM_NAME_FAVORITE ) items.push_back( ITEM_FAVORITE );
+        if( *it == ITEM_NAME_DELETE ) items.push_back( ITEM_DELETE );
+        if( *it == ITEM_NAME_QUIT ) items.push_back( ITEM_QUIT );
+
+        if( *it == ITEM_NAME_NEWARTICLE ) items.push_back( ITEM_NEWARTICLE );
+        if( *it == ITEM_NAME_SEARCHBOX ) items.push_back( ITEM_SEARCHBOX );
+        if( *it == ITEM_NAME_SEARCH_NEXT ) items.push_back( ITEM_SEARCH_NEXT );
+        if( *it == ITEM_NAME_SEARCH_PREV ) items.push_back( ITEM_SEARCH_PREV );
+
+        if( *it == ITEM_NAME_INSERTTEXT ) items.push_back( ITEM_INSERTTEXT );
+        if( *it == ITEM_NAME_NOTCLOSE ) items.push_back( ITEM_NOTCLOSE );
+        if( *it == ITEM_NAME_PREVIEW ) items.push_back( ITEM_PREVIEW );
+        if( *it == ITEM_NAME_UNDO ) items.push_back( ITEM_UNDO );
+    }
+    items.push_back( ITEM_END );
+
+    return items;
+}
+
+
 void read_list_urls( JDLIB::ConfLoader& cf, const std::string& id_urls, const std::string& id_locked,
                      std::list< std::string >& list_urls , std::list< bool >& list_locked )
 {
@@ -161,6 +236,9 @@ void SESSION::init_session()
     // 2chログイン
     mode_login2ch = cf.get_option( "mode_login2ch", false );
 
+    // beログイン
+    mode_loginbe = cf.get_option( "mode_loginbe", false );
+
     // paneのモード
     mode_pane = cf.get_option( "mode_pane", 0 );
 
@@ -202,16 +280,74 @@ void SESSION::init_session()
     read_list_urls( cf, "article_urls", "article_locked", article_urls, article_locked );
     read_list_urls( cf, "image_urls", "image_locked", image_urls, image_locked );
 
-    items_board = cf.get_option( "items_board",
-                                 COLUMN_TITLE_MARK + std::string ( " " ) +
-                                 COLUMN_TITLE_ID + std::string ( " " ) +
-                                 COLUMN_TITLE_NAME + std::string ( " " ) +
-                                 COLUMN_TITLE_RES + std::string ( " " ) +
-                                 COLUMN_TITLE_LOAD + std::string ( " " ) +
-                                 COLUMN_TITLE_NEW + std::string ( " " ) +
-                                 COLUMN_TITLE_SINCE + std::string ( " " ) +
-                                 COLUMN_TITLE_WRITE + std::string ( " " ) +
-                                 COLUMN_TITLE_SPEED + std::string ( " " ) );
+    items_sidebar_str = cf.get_option( "items_sidebar",
+                                 ITEM_NAME_SEARCHBOX + std::string ( " " ) +
+                                 ITEM_NAME_SEARCH_NEXT + std::string ( " " ) +
+                                 ITEM_NAME_SEARCH_PREV + std::string ( " " ) );
+
+    items_sidebar =  parse_items( items_sidebar_str );
+
+    items_main_toolbar_str = cf.get_option( "items_main_toolbar",
+                                 ITEM_NAME_BBSLISTVIEW + std::string ( " " ) +
+                                 ITEM_NAME_FAVORITEVIEW + std::string ( " " ) +
+                                 ITEM_NAME_BOARDVIEW + std::string ( " " ) +
+                                 ITEM_NAME_ARTICLEVIEW + std::string ( " " ) +
+                                 ITEM_NAME_IMAGEVIEW + std::string ( " " ) +
+                                 ITEM_NAME_SEPARATOR + std::string ( " " ) +
+                                 ITEM_NAME_URL + std::string ( " " ) +
+                                 ITEM_NAME_GO + std::string ( " " ) );
+
+    items_main_toolbar =  parse_items( items_main_toolbar_str );
+
+    items_article_toolbar_str = cf.get_option( "items_article_toolbar",
+                                 ITEM_NAME_WRITEMSG + std::string ( " " ) +
+                                 ITEM_NAME_OPENBOARD + std::string ( " " ) +
+                                 ITEM_NAME_NAME + std::string ( " " ) +
+                                 ITEM_NAME_SEARCH + std::string ( " " ) +
+                                 ITEM_NAME_RELOAD + std::string ( " " ) +
+                                 ITEM_NAME_STOPLOADING + std::string ( " " ) +
+                                 ITEM_NAME_FAVORITE + std::string ( " " ) +
+                                 ITEM_NAME_DELETE + std::string ( " " ) +
+                                 ITEM_NAME_QUIT + std::string ( " " ) );
+
+    items_article_toolbar =  parse_items( items_article_toolbar_str );
+
+    items_board_toolbar_str = cf.get_option( "items_board_toolbar",
+                                 ITEM_NAME_NEWARTICLE + std::string ( " " ) +
+                                 ITEM_NAME_SEARCHBOX + std::string ( " " ) +
+                                 ITEM_NAME_SEARCH_NEXT + std::string ( " " ) +
+                                 ITEM_NAME_SEARCH_PREV + std::string ( " " ) +
+                                 ITEM_NAME_RELOAD + std::string ( " " ) +
+                                 ITEM_NAME_STOPLOADING + std::string ( " " ) +
+                                 ITEM_NAME_FAVORITE + std::string ( " " ) +
+                                 ITEM_NAME_DELETE + std::string ( " " ) +
+                                 ITEM_NAME_QUIT + std::string ( " " ) );
+
+    items_board_toolbar =  parse_items( items_board_toolbar_str );
+
+    items_board_str = cf.get_option( "items_board",
+                                 ITEM_NAME_MARK + std::string ( " " ) +
+                                 ITEM_NAME_ID + std::string ( " " ) +
+                                 ITEM_NAME_NAME + std::string ( " " ) +
+                                 ITEM_NAME_RES + std::string ( " " ) +
+                                 ITEM_NAME_LOAD + std::string ( " " ) +
+                                 ITEM_NAME_NEW + std::string ( " " ) +
+                                 ITEM_NAME_SINCE + std::string ( " " ) +
+                                 ITEM_NAME_LASTWRITE + std::string ( " " ) +
+                                 ITEM_NAME_SPEED + std::string ( " " ) );
+
+    items_board =  parse_items( items_board_str );
+
+    items_msg_toolbar_str = cf.get_option( "items_msg_toolbar",
+                                 ITEM_NAME_PREVIEW + std::string ( " " ) +
+                                 ITEM_NAME_WRITEMSG+ std::string ( " " ) +
+                                 ITEM_NAME_NAME + std::string ( " " ) +
+                                 ITEM_NAME_UNDO + std::string ( " " ) +
+                                 ITEM_NAME_INSERTTEXT + std::string ( " " ) +
+                                 ITEM_NAME_NOTCLOSE + std::string ( " " ) +
+                                 ITEM_NAME_QUIT + std::string ( " " ) );
+
+    items_msg_toolbar =  parse_items( items_msg_toolbar_str );
 
     board_col_mark = cf.get_option( "col_mark", 30 );
     board_col_id = cf.get_option( "col_id", 45 );
@@ -245,6 +381,14 @@ void SESSION::init_session()
 
     popupmenu_shown = false;
 
+    // ディストリ判定( "/etc/issue.net"の一行目を読む )
+    std::string issue_net;
+    if( CACHE::load_rawdata( CACHE::path_issue_net(), issue_net ) )
+    {
+    	const size_t lf_pos = issue_net.find( "\n" );
+    	distribution = MISC::remove_spaces( issue_net.substr( 0, lf_pos ) );
+    }
+
     // WM 判定
     // TODO: 環境変数で判定できない場合の判定方法を考える
     win_manager = WM_UNKNON;
@@ -373,6 +517,7 @@ void SESSION::save_session()
     oss << "mode_pane = " << mode_pane << std::endl
         << "mode_online = " << mode_online << std::endl
         << "mode_login2ch = " << mode_login2ch << std::endl
+        << "mode_loginbe = " << mode_loginbe << std::endl
         << "x = " << x_win_main << std::endl
         << "y = " << y_win_main << std::endl
         << "width = " << width_win_main << std::endl
@@ -410,7 +555,13 @@ void SESSION::save_session()
         << "image_urls = " << str_image_urls << std::endl
         << "image_locked = " << str_image_locked << std::endl
 
-        << "items_board = " << items_board << std::endl
+        << "items_sidebar = " << items_sidebar_str << std::endl
+        << "items_main_toolbar = " << items_main_toolbar_str << std::endl
+        << "items_article_toolbar = " << items_article_toolbar_str << std::endl
+        << "items_board_toolbar = " << items_board_toolbar_str << std::endl
+        << "items_board = " << items_board_str << std::endl
+        << "items_msg_toolbar = " << items_msg_toolbar_str << std::endl
+
         << "col_mark = " << board_col_mark << std::endl
         << "col_id = " << board_col_id << std::endl
         << "col_subject = " << board_col_subject << std::endl
@@ -446,6 +597,16 @@ void SESSION::save_session()
 
 }
 
+// ブート中
+const bool SESSION::is_booting(){ return booting; }
+void SESSION::set_booting( bool boot ){ booting = boot; }
+
+// 終了中
+const bool SESSION::is_quitting(){ return quitting; }
+void SESSION::set_quitting( bool quit ){ quitting = quit; }
+
+// ディストリ判定
+const std::string& SESSION::get_distribution(){ return distribution; }
 
 // WM 判定
 const int SESSION::get_wm(){ return win_manager; }
@@ -459,6 +620,9 @@ void SESSION::set_online( bool mode ){ mode_online = mode; }
 const bool SESSION::login2ch(){ return mode_login2ch; }
 void SESSION::set_login2ch( bool login ){ mode_login2ch = login; }
 
+const bool SESSION::loginbe(){ return mode_loginbe; }
+void SESSION::set_loginbe( bool login ){ mode_loginbe = login; }
+
 const bool SESSION::show_sidebar(){ return win_show_sidebar; }
 
 const bool SESSION::show_menubar(){ return win_show_menubar; }
@@ -623,9 +787,60 @@ void SESSION::set_image_URLs( const std::list< std::string >& urls ){ image_urls
 const std::list< bool >& SESSION::get_image_locked(){ return image_locked; }
 void SESSION::set_image_locked( const std::list< bool >& locked ){ image_locked = locked; }
 
+// サイドバーのツールバーの項目
+const std::string& SESSION::get_items_sidebar_str(){ return items_sidebar_str; }
+void SESSION::set_items_sidebar_str( const std::string& items_str )
+{
+    items_sidebar_str = items_str;
+    items_sidebar = parse_items( items_sidebar_str );
+}
+const int SESSION::get_item_sidebar( const int num ){ return items_sidebar[ num ]; }
+
+// メインツールバーの項目
+const std::string& SESSION::get_items_main_toolbar_str(){ return items_main_toolbar_str; }
+void SESSION::set_items_main_toolbar_str( const std::string& items_str )
+{
+    items_main_toolbar_str = items_str;
+    items_main_toolbar = parse_items( items_main_toolbar_str );
+}
+const int SESSION::get_item_main_toolbar( const int num ){ return items_main_toolbar[ num ]; }
+
+// スレビューのツールバーの項目
+const std::string& SESSION::get_items_article_toolbar_str(){ return items_article_toolbar_str; }
+void SESSION::set_items_article_toolbar_str( const std::string& items_str )
+{
+    items_article_toolbar_str = items_str;
+    items_article_toolbar = parse_items( items_article_toolbar_str );
+}
+const int SESSION::get_item_article_toolbar( const int num ){ return items_article_toolbar[ num ]; }
+
+// スレ一覧のツールバー項目
+const std::string& SESSION::get_items_board_toolbar_str(){ return items_board_toolbar_str; }
+void SESSION::set_items_board_toolbar_str( const std::string& items_str )
+{
+    items_board_toolbar_str = items_str;
+    items_board_toolbar = parse_items( items_board_toolbar_str );
+}
+const int SESSION::get_item_board_toolbar( const int num ){ return items_board_toolbar[ num ]; }
+
 // スレ一覧の項目
-const std::string& SESSION::get_items_board(){ return items_board; }
-void SESSION::set_items_board( const std::string& items ){ items_board = items; }
+const std::string& SESSION::get_items_board_str(){ return items_board_str; }
+void SESSION::set_items_board_str( const std::string& items_str )
+{
+    items_board_str = items_str;
+    items_board = parse_items( items_board_str );
+}
+const int SESSION::get_item_board( const int num ){ return items_board[ num ]; }
+
+// 書き込みビューのツールバー項目
+const std::string& SESSION::get_items_msg_toolbar_str(){ return items_msg_toolbar_str; }
+void SESSION::set_items_msg_toolbar_str( const std::string& items_str )
+{
+    items_msg_toolbar_str = items_str;
+    items_msg_toolbar = parse_items( items_msg_toolbar_str );
+}
+const int SESSION::get_item_msg_toolbar( const int num ){ return items_msg_toolbar[ num ]; }
+
 
 // board ビューの列幅
 int SESSION::col_mark(){ return board_col_mark; }
